"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AccountStakeDeltaRawMapper = exports.StakeobsvRawMapper = exports.AccountStakeDeltaMongoMapper = exports.StakeobsvMongoMapper = void 0;
const aw_core_1 = require("@alien-worlds/aw-core");
const aw_storage_mongodb_1 = require("@alien-worlds/aw-storage-mongodb");
const aw_antelope_1 = require("@alien-worlds/aw-antelope");
const entities_1 = require("../../domain/entities");
class StakeobsvMongoMapper extends aw_storage_mongodb_1.MongoMapper {
    constructor() {
        super();
        this.mappingFromEntity.set('stakeDeltas', {
            key: 'stake_deltas',
            mapper: (values) => values.map(value => new AccountStakeDeltaMongoMapper().fromEntity(value)),
        });
        this.mappingFromEntity.set('dacId', {
            key: 'dac_id',
            mapper: (value) => value,
        });
    }
    toEntity(mongoModel) {
        const { stake_deltas, dac_id, _id, ...rest } = mongoModel;
        return entities_1.Stakeobsv.create(stake_deltas?.map(value => new AccountStakeDeltaMongoMapper().toEntity(value)) || [], dac_id || '', _id instanceof aw_storage_mongodb_1.MongoDB.ObjectId ? _id.toString() : undefined, rest);
    }
}
exports.StakeobsvMongoMapper = StakeobsvMongoMapper;
class AccountStakeDeltaMongoMapper extends aw_storage_mongodb_1.MongoMapper {
    constructor() {
        super();
        this.mappingFromEntity.set('account', {
            key: 'account',
            mapper: (value) => value,
        });
        this.mappingFromEntity.set('stakeDelta', {
            key: 'stake_delta',
            mapper: (value) => new aw_antelope_1.AssetMongoMapper().fromEntity(value),
        });
        this.mappingFromEntity.set('unstakeDelay', {
            key: 'unstake_delay',
            mapper: (value) => value,
        });
    }
    toEntity(mongoModel) {
        const { account, stake_delta, unstake_delay, _id, ...rest } = mongoModel;
        return entities_1.AccountStakeDelta.create(account || '', stake_delta ? new aw_antelope_1.AssetMongoMapper().toEntity(stake_delta) : aw_antelope_1.Asset.getDefault(), unstake_delay || 0, _id instanceof aw_storage_mongodb_1.MongoDB.ObjectId ? _id.toString() : undefined, rest);
    }
}
exports.AccountStakeDeltaMongoMapper = AccountStakeDeltaMongoMapper;
class StakeobsvRawMapper extends aw_core_1.MapperImpl {
    fromEntity(entity) {
        throw new Error('Method not implemented');
    }
    toEntity(rawModel) {
        const { stake_deltas, dac_id, ...rest } = rawModel;
        return entities_1.Stakeobsv.create(stake_deltas?.map(value => new AccountStakeDeltaRawMapper().toEntity(value)) || [], dac_id || '', undefined, rest);
    }
}
exports.StakeobsvRawMapper = StakeobsvRawMapper;
class AccountStakeDeltaRawMapper extends aw_core_1.MapperImpl {
    fromEntity(entity) {
        throw new Error('Method not implemented');
    }
    toEntity(rawModel) {
        const { account, stake_delta, unstake_delay, ...rest } = rawModel;
        return entities_1.AccountStakeDelta.create(account || '', stake_delta ? new aw_antelope_1.AssetRawMapper().toEntity(stake_delta) : aw_antelope_1.Asset.getDefault(), unstake_delay || 0, undefined, rest);
    }
}
exports.AccountStakeDeltaRawMapper = AccountStakeDeltaRawMapper;
