"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StkvtWorldsActionProcessorTaskMapper = exports.StkvtWorldsActionMongoMapper = void 0;
const aw_core_1 = require("@alien-worlds/aw-core");
const balanceobsv_mapper_1 = require("./balanceobsv.mapper");
const stakeobsv_mapper_1 = require("./stakeobsv.mapper");
const updateconfig_mapper_1 = require("./updateconfig.mapper");
const aw_storage_mongodb_1 = require("@alien-worlds/aw-storage-mongodb");
const enums_1 = require("../../domain/enums");
class StkvtWorldsActionMongoMapper extends aw_storage_mongodb_1.MongoMapper {
    fromEntity(entity) {
        let entityData;
        switch (entity.name) {
            case enums_1.StkvtWorldsActionName.Balanceobsv:
                entityData = new balanceobsv_mapper_1.BalanceobsvMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.StkvtWorldsActionName.Stakeobsv:
                entityData = new stakeobsv_mapper_1.StakeobsvMongoMapper().fromEntity(entity.data);
                break;
            case enums_1.StkvtWorldsActionName.Updateconfig:
                entityData = new updateconfig_mapper_1.UpdateconfigMongoMapper().fromEntity(entity.data);
                break;
        }
        const model = {
            block_timestamp: entity.blockTimestamp,
            block_num: new aw_storage_mongodb_1.MongoDB.Long(entity.blockNumber),
            global_sequence: new aw_storage_mongodb_1.MongoDB.Long(entity.globalSequence),
            recv_sequence: new aw_storage_mongodb_1.MongoDB.Long(entity.receiverSequence),
            trx_id: entity.transactionId,
            action: {
                name: entity.name,
                account: entity.account,
                data: entityData,
            },
        };
        if (entity.id && aw_storage_mongodb_1.MongoDB.ObjectId.isValid(entity.id)) {
            model._id = new aw_storage_mongodb_1.MongoDB.ObjectId(entity.id);
        }
        return model;
    }
    toEntity(mongoModel) {
        let data;
        switch (mongoModel.action.name) {
            case enums_1.StkvtWorldsActionName.Balanceobsv:
                data = new balanceobsv_mapper_1.BalanceobsvMongoMapper().toEntity(mongoModel.action.data);
                break;
            case enums_1.StkvtWorldsActionName.Stakeobsv:
                data = new stakeobsv_mapper_1.StakeobsvMongoMapper().toEntity(mongoModel.action.data);
                break;
            case enums_1.StkvtWorldsActionName.Updateconfig:
                data = new updateconfig_mapper_1.UpdateconfigMongoMapper().toEntity(mongoModel.action.data);
                break;
        }
        const { _id, block_timestamp, block_num, global_sequence, recv_sequence, trx_id, action, } = mongoModel;
        return new aw_core_1.ContractAction(_id.toString(), block_timestamp, (0, aw_core_1.parseToBigInt)(block_num), action.account, action.name, (0, aw_core_1.parseToBigInt)(global_sequence), (0, aw_core_1.parseToBigInt)(recv_sequence), trx_id, data);
    }
}
exports.StkvtWorldsActionMongoMapper = StkvtWorldsActionMongoMapper;
class StkvtWorldsActionProcessorTaskMapper extends aw_core_1.MapperImpl {
    fromEntity(entity) {
        throw new Error('method not implemented');
    }
    toEntity(rawModel) {
        let data;
        switch (rawModel.name) {
            case enums_1.StkvtWorldsActionName.Balanceobsv:
                data = new balanceobsv_mapper_1.BalanceobsvRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.StkvtWorldsActionName.Stakeobsv:
                data = new stakeobsv_mapper_1.StakeobsvRawMapper().toEntity(rawModel.data);
                break;
            case enums_1.StkvtWorldsActionName.Updateconfig:
                data = new updateconfig_mapper_1.UpdateconfigRawMapper().toEntity(rawModel.data);
                break;
        }
        const { account, name, block_timestamp, block_num, global_sequence, recv_sequence, transaction_id, } = rawModel;
        return new aw_core_1.ContractAction('', block_timestamp, (0, aw_core_1.parseToBigInt)(block_num), account, name, (0, aw_core_1.parseToBigInt)(global_sequence), (0, aw_core_1.parseToBigInt)(recv_sequence), transaction_id, data);
    }
}
exports.StkvtWorldsActionProcessorTaskMapper = StkvtWorldsActionProcessorTaskMapper;
