"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupStkvtWorldsContractService = exports.setupStkvtWorldsDeltaRepository = exports.setupStkvtWorldsActionRepository = void 0;
const aw_core_1 = require("@alien-worlds/aw-core");
const aw_storage_mongodb_1 = require("@alien-worlds/aw-storage-mongodb");
const mappers_1 = require("./actions/data/mappers");
const data_sources_1 = require("./actions/data/data-sources");
const repositories_1 = require("./actions/domain/repositories");
const stkvt_worlds_contract_service_1 = require("./services/stkvt-worlds-contract.service");
const stkvt_worlds_contract_service_impl_1 = require("./services/stkvt-worlds-contract.service-impl");
const mappers_2 = require("./deltas/data/mappers");
const data_sources_2 = require("./deltas/data/data-sources");
const repositories_2 = require("./deltas/domain/repositories");
const setupStkvtWorldsActionRepository = async (mongo, container) => {
    let mongoSource;
    if (mongo instanceof aw_storage_mongodb_1.MongoSource) {
        mongoSource = mongo;
    }
    else {
        mongoSource = await aw_storage_mongodb_1.MongoSource.create(mongo);
    }
    const mapper = new mappers_1.StkvtWorldsActionMongoMapper();
    const repository = new aw_core_1.RepositoryImpl(new data_sources_1.StkvtWorldsActionMongoSource(mongoSource), mapper, new aw_storage_mongodb_1.MongoQueryBuilders(mapper));
    if (container) {
        container
            .bind(repositories_1.StkvtWorldsActionRepository.Token)
            .toConstantValue(repository);
    }
    return repository;
};
exports.setupStkvtWorldsActionRepository = setupStkvtWorldsActionRepository;
const setupStkvtWorldsDeltaRepository = async (mongo, container) => {
    let mongoSource;
    if (mongo instanceof aw_storage_mongodb_1.MongoSource) {
        mongoSource = mongo;
    }
    else {
        mongoSource = await aw_storage_mongodb_1.MongoSource.create(mongo);
    }
    const mapper = new mappers_2.StkvtWorldsDeltaMongoMapper();
    const repository = new aw_core_1.RepositoryImpl(new data_sources_2.StkvtWorldsDeltaMongoSource(mongoSource), mapper, new aw_storage_mongodb_1.MongoQueryBuilders(mapper));
    if (container) {
        container
            .bind(repositories_2.StkvtWorldsDeltaRepository.Token)
            .toConstantValue(repository);
    }
    return repository;
};
exports.setupStkvtWorldsDeltaRepository = setupStkvtWorldsDeltaRepository;
const setupStkvtWorldsContractService = (antelopeRpcSourceImpl, serviceUrl, container) => {
    const service = new stkvt_worlds_contract_service_impl_1.StkvtWorldsContractServiceImpl(antelopeRpcSourceImpl, serviceUrl);
    if (container) {
        container
            .bind(stkvt_worlds_contract_service_1.StkvtWorldsContractService.Token)
            .toConstantValue(service);
    }
    return service;
};
exports.setupStkvtWorldsContractService = setupStkvtWorldsContractService;
